@@ -29,3 +29,6 @@ def json_response(obj):
 
 
 AIRFLOW_VERSION_2 = LooseVersion(airflow.version.version) >= LooseVersion("2.0.0")
+AIRFLOW_VERSION_BEFORE_2_2 = LooseVersion(airflow.version.version) < LooseVersion(
+    "2.2.0"
+)
